@@ -99,16 +99,29 @@ CancelJournalKinesisStreamResponseTypeDef = TypedDict(
     },
 )
 
-CreateLedgerRequestRequestTypeDef = TypedDict(
-    "CreateLedgerRequestRequestTypeDef",
+_RequiredCreateLedgerRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLedgerRequestRequestTypeDef",
     {
         "Name": str,
         "PermissionsMode": PermissionsModeType,
-        "Tags": NotRequired[Mapping[str, str]],
-        "DeletionProtection": NotRequired[bool],
-        "KmsKey": NotRequired[str],
     },
 )
+_OptionalCreateLedgerRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLedgerRequestRequestTypeDef",
+    {
+        "Tags": Mapping[str, str],
+        "DeletionProtection": bool,
+        "KmsKey": str,
+    },
+    total=False,
+)
+
+
+class CreateLedgerRequestRequestTypeDef(
+    _RequiredCreateLedgerRequestRequestTypeDef, _OptionalCreateLedgerRequestRequestTypeDef
+):
+    pass
+
 
 CreateLedgerResponseTypeDef = TypedDict(
     "CreateLedgerResponseTypeDef",
@@ -184,17 +197,30 @@ DescribeLedgerResponseTypeDef = TypedDict(
     },
 )
 
-ExportJournalToS3RequestRequestTypeDef = TypedDict(
-    "ExportJournalToS3RequestRequestTypeDef",
+_RequiredExportJournalToS3RequestRequestTypeDef = TypedDict(
+    "_RequiredExportJournalToS3RequestRequestTypeDef",
     {
         "Name": str,
         "InclusiveStartTime": Union[datetime, str],
         "ExclusiveEndTime": Union[datetime, str],
         "S3ExportConfiguration": "S3ExportConfigurationTypeDef",
         "RoleArn": str,
-        "OutputFormat": NotRequired[OutputFormatType],
     },
 )
+_OptionalExportJournalToS3RequestRequestTypeDef = TypedDict(
+    "_OptionalExportJournalToS3RequestRequestTypeDef",
+    {
+        "OutputFormat": OutputFormatType,
+    },
+    total=False,
+)
+
+
+class ExportJournalToS3RequestRequestTypeDef(
+    _RequiredExportJournalToS3RequestRequestTypeDef, _OptionalExportJournalToS3RequestRequestTypeDef
+):
+    pass
+
 
 ExportJournalToS3ResponseTypeDef = TypedDict(
     "ExportJournalToS3ResponseTypeDef",
@@ -204,14 +230,27 @@ ExportJournalToS3ResponseTypeDef = TypedDict(
     },
 )
 
-GetBlockRequestRequestTypeDef = TypedDict(
-    "GetBlockRequestRequestTypeDef",
+_RequiredGetBlockRequestRequestTypeDef = TypedDict(
+    "_RequiredGetBlockRequestRequestTypeDef",
     {
         "Name": str,
         "BlockAddress": "ValueHolderTypeDef",
-        "DigestTipAddress": NotRequired["ValueHolderTypeDef"],
     },
 )
+_OptionalGetBlockRequestRequestTypeDef = TypedDict(
+    "_OptionalGetBlockRequestRequestTypeDef",
+    {
+        "DigestTipAddress": "ValueHolderTypeDef",
+    },
+    total=False,
+)
+
+
+class GetBlockRequestRequestTypeDef(
+    _RequiredGetBlockRequestRequestTypeDef, _OptionalGetBlockRequestRequestTypeDef
+):
+    pass
+
 
 GetBlockResponseTypeDef = TypedDict(
     "GetBlockResponseTypeDef",
@@ -238,15 +277,28 @@ GetDigestResponseTypeDef = TypedDict(
     },
 )
 
-GetRevisionRequestRequestTypeDef = TypedDict(
-    "GetRevisionRequestRequestTypeDef",
+_RequiredGetRevisionRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRevisionRequestRequestTypeDef",
     {
         "Name": str,
         "BlockAddress": "ValueHolderTypeDef",
         "DocumentId": str,
-        "DigestTipAddress": NotRequired["ValueHolderTypeDef"],
     },
 )
+_OptionalGetRevisionRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRevisionRequestRequestTypeDef",
+    {
+        "DigestTipAddress": "ValueHolderTypeDef",
+    },
+    total=False,
+)
+
+
+class GetRevisionRequestRequestTypeDef(
+    _RequiredGetRevisionRequestRequestTypeDef, _OptionalGetRevisionRequestRequestTypeDef
+):
+    pass
+
 
 GetRevisionResponseTypeDef = TypedDict(
     "GetRevisionResponseTypeDef",
@@ -257,8 +309,8 @@ GetRevisionResponseTypeDef = TypedDict(
     },
 )
 
-JournalKinesisStreamDescriptionTypeDef = TypedDict(
-    "JournalKinesisStreamDescriptionTypeDef",
+_RequiredJournalKinesisStreamDescriptionTypeDef = TypedDict(
+    "_RequiredJournalKinesisStreamDescriptionTypeDef",
     {
         "LedgerName": str,
         "RoleArn": str,
@@ -266,16 +318,29 @@ JournalKinesisStreamDescriptionTypeDef = TypedDict(
         "Status": StreamStatusType,
         "KinesisConfiguration": "KinesisConfigurationTypeDef",
         "StreamName": str,
-        "CreationTime": NotRequired[datetime],
-        "InclusiveStartTime": NotRequired[datetime],
-        "ExclusiveEndTime": NotRequired[datetime],
-        "Arn": NotRequired[str],
-        "ErrorCause": NotRequired[ErrorCauseType],
     },
 )
+_OptionalJournalKinesisStreamDescriptionTypeDef = TypedDict(
+    "_OptionalJournalKinesisStreamDescriptionTypeDef",
+    {
+        "CreationTime": datetime,
+        "InclusiveStartTime": datetime,
+        "ExclusiveEndTime": datetime,
+        "Arn": str,
+        "ErrorCause": ErrorCauseType,
+    },
+    total=False,
+)
 
-JournalS3ExportDescriptionTypeDef = TypedDict(
-    "JournalS3ExportDescriptionTypeDef",
+
+class JournalKinesisStreamDescriptionTypeDef(
+    _RequiredJournalKinesisStreamDescriptionTypeDef, _OptionalJournalKinesisStreamDescriptionTypeDef
+):
+    pass
+
+
+_RequiredJournalS3ExportDescriptionTypeDef = TypedDict(
+    "_RequiredJournalS3ExportDescriptionTypeDef",
     {
         "LedgerName": str,
         "ExportId": str,
@@ -285,44 +350,98 @@ JournalS3ExportDescriptionTypeDef = TypedDict(
         "ExclusiveEndTime": datetime,
         "S3ExportConfiguration": "S3ExportConfigurationTypeDef",
         "RoleArn": str,
-        "OutputFormat": NotRequired[OutputFormatType],
     },
 )
+_OptionalJournalS3ExportDescriptionTypeDef = TypedDict(
+    "_OptionalJournalS3ExportDescriptionTypeDef",
+    {
+        "OutputFormat": OutputFormatType,
+    },
+    total=False,
+)
 
-KinesisConfigurationTypeDef = TypedDict(
-    "KinesisConfigurationTypeDef",
+
+class JournalS3ExportDescriptionTypeDef(
+    _RequiredJournalS3ExportDescriptionTypeDef, _OptionalJournalS3ExportDescriptionTypeDef
+):
+    pass
+
+
+_RequiredKinesisConfigurationTypeDef = TypedDict(
+    "_RequiredKinesisConfigurationTypeDef",
     {
         "StreamArn": str,
-        "AggregationEnabled": NotRequired[bool],
     },
 )
+_OptionalKinesisConfigurationTypeDef = TypedDict(
+    "_OptionalKinesisConfigurationTypeDef",
+    {
+        "AggregationEnabled": bool,
+    },
+    total=False,
+)
 
-LedgerEncryptionDescriptionTypeDef = TypedDict(
-    "LedgerEncryptionDescriptionTypeDef",
+
+class KinesisConfigurationTypeDef(
+    _RequiredKinesisConfigurationTypeDef, _OptionalKinesisConfigurationTypeDef
+):
+    pass
+
+
+_RequiredLedgerEncryptionDescriptionTypeDef = TypedDict(
+    "_RequiredLedgerEncryptionDescriptionTypeDef",
     {
         "KmsKeyArn": str,
         "EncryptionStatus": EncryptionStatusType,
-        "InaccessibleKmsKeyDateTime": NotRequired[datetime],
     },
 )
+_OptionalLedgerEncryptionDescriptionTypeDef = TypedDict(
+    "_OptionalLedgerEncryptionDescriptionTypeDef",
+    {
+        "InaccessibleKmsKeyDateTime": datetime,
+    },
+    total=False,
+)
+
+
+class LedgerEncryptionDescriptionTypeDef(
+    _RequiredLedgerEncryptionDescriptionTypeDef, _OptionalLedgerEncryptionDescriptionTypeDef
+):
+    pass
+
 
 LedgerSummaryTypeDef = TypedDict(
     "LedgerSummaryTypeDef",
     {
-        "Name": NotRequired[str],
-        "State": NotRequired[LedgerStateType],
-        "CreationDateTime": NotRequired[datetime],
+        "Name": str,
+        "State": LedgerStateType,
+        "CreationDateTime": datetime,
     },
+    total=False,
 )
 
-ListJournalKinesisStreamsForLedgerRequestRequestTypeDef = TypedDict(
-    "ListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
+_RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef = TypedDict(
+    "_RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
     {
         "LedgerName": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef = TypedDict(
+    "_OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListJournalKinesisStreamsForLedgerRequestRequestTypeDef(
+    _RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef,
+    _OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef,
+):
+    pass
+
 
 ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
     "ListJournalKinesisStreamsForLedgerResponseTypeDef",
@@ -333,14 +452,28 @@ ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
     },
 )
 
-ListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
-    "ListJournalS3ExportsForLedgerRequestRequestTypeDef",
+_RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
+    "_RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef",
     {
         "Name": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
+    "_OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListJournalS3ExportsForLedgerRequestRequestTypeDef(
+    _RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef,
+    _OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef,
+):
+    pass
+
 
 ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
     "ListJournalS3ExportsForLedgerResponseTypeDef",
@@ -354,9 +487,10 @@ ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
 ListJournalS3ExportsRequestRequestTypeDef = TypedDict(
     "ListJournalS3ExportsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListJournalS3ExportsResponseTypeDef = TypedDict(
@@ -371,9 +505,10 @@ ListJournalS3ExportsResponseTypeDef = TypedDict(
 ListLedgersRequestRequestTypeDef = TypedDict(
     "ListLedgersRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListLedgersResponseTypeDef = TypedDict(
@@ -411,13 +546,26 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-S3EncryptionConfigurationTypeDef = TypedDict(
-    "S3EncryptionConfigurationTypeDef",
+_RequiredS3EncryptionConfigurationTypeDef = TypedDict(
+    "_RequiredS3EncryptionConfigurationTypeDef",
     {
         "ObjectEncryptionType": S3ObjectEncryptionTypeType,
-        "KmsKeyArn": NotRequired[str],
     },
 )
+_OptionalS3EncryptionConfigurationTypeDef = TypedDict(
+    "_OptionalS3EncryptionConfigurationTypeDef",
+    {
+        "KmsKeyArn": str,
+    },
+    total=False,
+)
+
+
+class S3EncryptionConfigurationTypeDef(
+    _RequiredS3EncryptionConfigurationTypeDef, _OptionalS3EncryptionConfigurationTypeDef
+):
+    pass
+
 
 S3ExportConfigurationTypeDef = TypedDict(
     "S3ExportConfigurationTypeDef",
@@ -428,18 +576,32 @@ S3ExportConfigurationTypeDef = TypedDict(
     },
 )
 
-StreamJournalToKinesisRequestRequestTypeDef = TypedDict(
-    "StreamJournalToKinesisRequestRequestTypeDef",
+_RequiredStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
+    "_RequiredStreamJournalToKinesisRequestRequestTypeDef",
     {
         "LedgerName": str,
         "RoleArn": str,
         "InclusiveStartTime": Union[datetime, str],
         "KinesisConfiguration": "KinesisConfigurationTypeDef",
         "StreamName": str,
-        "Tags": NotRequired[Mapping[str, str]],
-        "ExclusiveEndTime": NotRequired[Union[datetime, str]],
     },
 )
+_OptionalStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
+    "_OptionalStreamJournalToKinesisRequestRequestTypeDef",
+    {
+        "Tags": Mapping[str, str],
+        "ExclusiveEndTime": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class StreamJournalToKinesisRequestRequestTypeDef(
+    _RequiredStreamJournalToKinesisRequestRequestTypeDef,
+    _OptionalStreamJournalToKinesisRequestRequestTypeDef,
+):
+    pass
+
 
 StreamJournalToKinesisResponseTypeDef = TypedDict(
     "StreamJournalToKinesisResponseTypeDef",
@@ -483,14 +645,27 @@ UpdateLedgerPermissionsModeResponseTypeDef = TypedDict(
     },
 )
 
-UpdateLedgerRequestRequestTypeDef = TypedDict(
-    "UpdateLedgerRequestRequestTypeDef",
+_RequiredUpdateLedgerRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLedgerRequestRequestTypeDef",
     {
         "Name": str,
-        "DeletionProtection": NotRequired[bool],
-        "KmsKey": NotRequired[str],
     },
 )
+_OptionalUpdateLedgerRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLedgerRequestRequestTypeDef",
+    {
+        "DeletionProtection": bool,
+        "KmsKey": str,
+    },
+    total=False,
+)
+
+
+class UpdateLedgerRequestRequestTypeDef(
+    _RequiredUpdateLedgerRequestRequestTypeDef, _OptionalUpdateLedgerRequestRequestTypeDef
+):
+    pass
+
 
 UpdateLedgerResponseTypeDef = TypedDict(
     "UpdateLedgerResponseTypeDef",
@@ -508,6 +683,7 @@ UpdateLedgerResponseTypeDef = TypedDict(
 ValueHolderTypeDef = TypedDict(
     "ValueHolderTypeDef",
     {
-        "IonText": NotRequired[str],
+        "IonText": str,
     },
+    total=False,
 )
